@@ -12,7 +12,6 @@ import os
 import re
 from enum import Enum, unique
 from functools import wraps
-from nose.tools import nottest
 
 try:
     import yaml
@@ -21,7 +20,7 @@ except ImportError:  # pragma: no cover
 else:
     _have_yaml = True
 
-__version__ = '1.4.0'
+__version__ = '1.4.1'
 
 # These attributes will not conflict with any real python attribute
 # They are added to the decorated test method and processed later
@@ -41,7 +40,6 @@ except NameError:
 
 
 @unique
-@nottest
 class TestNameFormat(Enum):
     """
     An enum to configure how ``mk_test_name()`` to compose a test name.  Given
